@@ -2,12 +2,13 @@ module Rails
   module Timeago
     module VERSION
       MAJOR = 2
-      MINOR = 11
-      PATCH = 1
+      MINOR = 16
+      PATCH = 0
       STAGE = nil
+      STRING = [MAJOR, MINOR, PATCH, STAGE].reject(&:nil?).join('.').freeze
 
       def self.to_s
-        [MAJOR, MINOR, PATCH, STAGE].reject(&:nil?).join '.'
+        STRING
       end
     end
   end
